@@ -1,5 +1,6 @@
 import calendar
 from datetime import date
+import time
 
 import pandas as pd
 
@@ -38,8 +39,16 @@ def processor(d_df, df_master, ssp_df, wacgu_dict, fy_year, month_dict):
         # subset the data
         data = d_df[month].copy()
         data['FormattedDate'] = data['ValueDate'].dt.date
-        start_date = min(data.sort_values(by='ValueDate')['ValueDate']) if len(data) else 0
-        end_date = max(data.sort_values(by='ValueDate')['ValueDate']) if len(data) else 0
+
+        month_num = time.strptime(month, "%B").tm_mon
+        year_num = fy_year - 1 if month_num > 6 else fy_year
+        last_day = calendar.monthrange(year_num, month_num)[-1]
+
+        start_date = min(data.sort_values(by='ValueDate')['ValueDate']) if len(data) else pd.Timestamp(
+            date(year_num, month_num, 1))
+        end_date = max(data.sort_values(by='ValueDate')['ValueDate']) if len(data) else pd.Timestamp(
+            date(year_num, month_num,
+                 last_day))
 
         submaster_dict = {}
 
@@ -215,7 +224,7 @@ for i in range(1, 13):
 # main wrapper function
 
 def main_execute():
-    print('Package run 23 executing...')
+    print('Package run 24 executing...')
 
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
